
# Slot: id


identifier for the interaction. This may come from an interaction database such as IMEX.

URI: [biolink:pairwise_molecular_interaction_id](https://w3id.org/biolink/vocab/pairwise_molecular_interaction_id)


## Domain and Range

[PairwiseMolecularInteraction](PairwiseMolecularInteraction.md) &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents

 *  is_a: [id](id.md)

## Children


## Used by

 * [PairwiseMolecularInteraction](PairwiseMolecularInteraction.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Examples:** | | Example(value='WB:WBInteraction000538741', description=None) |

